@@ -34,8 +34,10 @@ void stats_lock(void);
 void stats_unlock(void);
 gboolean stats_check_level(gint level);
 StatsCluster *stats_register_counter(gint level, const StatsClusterKey *sc_key, gint type, StatsCounterItem **counter);
-StatsCluster *stats_register_counter_and_index(gint level, const StatsClusterKey *sc_key, gint type, StatsCounterItem **counter);
-StatsCluster *stats_register_dynamic_counter(gint stats_level, const StatsClusterKey *sc_key, gint type, StatsCounterItem **counter);
+StatsCluster *stats_register_counter_and_index(gint level, const StatsClusterKey *sc_key, gint type,
+                                               StatsCounterItem **counter);
+StatsCluster *stats_register_dynamic_counter(gint stats_level, const StatsClusterKey *sc_key, gint type,
+                                             StatsCounterItem **counter);
 void stats_register_and_increment_dynamic_counter(gint stats_level, const StatsClusterKey *sc_key, time_t timestamp);
 void stats_register_associated_counter(StatsCluster *handle, gint type, StatsCounterItem **counter);
 void stats_unregister_counter(const StatsClusterKey *sc_key, gint type, StatsCounterItem **counter);
@@ -50,9 +52,10 @@ void stats_foreach_cluster_remove(StatsForeachClusterRemoveFunc func, gpointer u
 void stats_registry_init(void);
 void stats_registry_deinit(void);
 
-GHashTable* stats_registry_get_container(void);
-
 void save_counter_to_persistent_storage(GlobalConfig *cfg, StatsCounterItem *counter);
 void load_counter_from_persistent_storage(GlobalConfig *cfg, StatsCounterItem *counter);
 
+gboolean stats_check_dynamic_clusters_limit(guint number_of_clusters);
+gint stats_number_of_dynamic_clusters_limit(void);
+
 #endif
